local function weapon_mod_stats_timer_adjust( mod_stats, other_data )
	local factory_id = managers.weapon_factory:get_factory_id_by_weapon_id(other_data.weapon_name)
	local default_blueprint = managers.weapon_factory:get_default_blueprint_by_factory_id(factory_id)

	for _, mod in pairs(mod_stats) do
		part_data = nil

		if mod.name then
			part_data = tweak_data.blackmarket.weapon_skins[mod.name] and tweak_data.blackmarket.weapon_skins[mod.name].bonus and tweak_data.economy.bonuses[tweak_data.blackmarket.weapon_skins[mod.name].bonus] and {stats = tweak_data.economy.bonuses[tweak_data.blackmarket.weapon_skins[mod.name].bonus].stats} or managers.weapon_factory:get_part_data_by_part_id_from_weapon(mod.name, factory_id, default_blueprint)
		end

		if part_data and ( part_data.timer_multiplier or part_data.timer_adder ) then
			local base_reload = other_data.base_stats["reload"].value or 0
			local reload_multiplier = ( (mod_stats["reload"] or 0) + base_reload) / base_reload

			local multiplier = 1
			if part_data.timer_multiplier and part_data.timer_multiplier["reload_empty"] then
				multiplier = part_data.timer_multiplier["reload_empty"]
			end

			local adder = 0
			if part_data.timer_adder and part_data.timer_adder["reload_empty"] then
				adder = part_data.timer_adder["reload_empty"]
			end

			mod["reload"] = ( ( base_reload * multiplier ) - base_reload + adder ) / reload_multiplier
		end
	end
end

WeaponDescription._get_weapon_mod_stats_attachment_animations_olde = WeaponDescription._get_weapon_mod_stats_attachment_animations_olde or WeaponDescription._get_weapon_mod_stats
function WeaponDescription._get_weapon_mod_stats(mod_name, weapon_name, base_stats, mods_stats, equipped_mods)
	local mod_stats = WeaponDescription._get_weapon_mod_stats_attachment_animations_olde( mod_name, weapon_name, base_stats, mods_stats, equipped_mods )

	weapon_mod_stats_timer_adjust( mod_stats, { mod_name = mod_name, weapon_name = weapon_name, base_stats = base_stats, mods_stats = mods_stats, equipped_mods = equipped_mods } )

	return mod_stats
end

local function mods_stats_timer_adjust( mods_stats, other_data )
	if other_data.equipped_mods then
		local tweak_stats = tweak_data.weapon.stats
		local tweak_factory = tweak_data.weapon.factory.parts
		local factory_id = managers.weapon_factory:get_factory_id_by_weapon_id(other_data.name)
		local default_blueprint = managers.weapon_factory:get_default_blueprint_by_factory_id(factory_id)

		local part_data = nil

		for _, mod in ipairs(other_data.equipped_mods) do
			part_data = managers.weapon_factory:get_part_data_by_part_id_from_weapon(mod, factory_id, default_blueprint)

			if part_data and ( part_data.timer_multiplier or part_data.timer_adder ) then
				local base_reload = other_data.base_stats["reload"].value  or 0
				local reload_multiplier = ( (mods_stats["reload"].value or 0) + base_reload) / base_reload

				local multiplier = 1
				if part_data.timer_multiplier and part_data.timer_multiplier["reload_empty"] then
					multiplier = part_data.timer_multiplier["reload_empty"]
				end

				local adder = 0
				if part_data.timer_adder and part_data.timer_adder["reload_empty"] then
					adder = part_data.timer_adder["reload_empty"]
				end

				mods_stats["reload"].value = ( ( base_reload * multiplier ) - base_reload + adder ) / reload_multiplier
			end
		end
	end
end

WeaponDescription._get_mods_stats_attachment_animations_olde = WeaponDescription._get_mods_stats_attachment_animations_olde or WeaponDescription._get_mods_stats
function WeaponDescription._get_mods_stats(name, base_stats, equipped_mods, bonus_stats)
	local mods_stats = WeaponDescription._get_mods_stats_attachment_animations_olde( name, base_stats, equipped_mods, bonus_stats )

	mods_stats_timer_adjust( mods_stats, { name = name, base_stats = base_stats, equipped_mods = equipped_mods, bonus_stats = bonus_stats } )

	return mods_stats
end